What's new in the latest versions
=================================

The new version of NoLOAD_Jax v1.1.6 is available!
The release is from 16th of September 2022.

.. toctree::
   :maxdepth: 2

   new_features/v1.1.6


Information about the latest versions
-------------------------------------

.. toctree::
   :maxdepth: 1

   new_features/v1.1.5
   new_features/v1.1.41
   new_features/v1.1.3
   new_features/v1.1.2
   new_features/v1.1.1
   new_features/v1.1.0
   new_features/v1.0.2
   new_features/v1.0.1



